#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
ezgooey.logging
---------------

Copyright (c) 2020 Adam Twardoch <adam+github@twardoch.com>
MIT license. Python 3.8+

Sets up a simple colorful logger,
compatible with Gooey's richtext control

## Simple usage

### Import and initialize in one place

```python
import ezgooey.logging as logging
logging.init()
```

### Use

```python
logging.info('info')
logging.warning('warning')
logging.error('error')
```

### In other places, just do:

```python
import logging
logging.info('info')
```

## Advanced usage

### Import and initialize in one place

```python
import ezgooey.logging as logging
logging.init(level=logging.INFO)
```

### In other places:

```python
import ezgooey.logging as logging
log = logging.logger('appname')
log.info('info')
log.warning('warning')
log.error('error')
log.success('success') # Only with adv
...
```
"""
__version__ = "1.2.0"

import sys
from logging import *
from colored import stylize, attr, fg

SUCCESS = 25

# Set up color logger

class Unbuffered(object):
    def __init__(self, stream):
        self.stream = stream

    def write(self, data):
        self.stream.write(data)
        self.stream.flush()

    def writelines(self, datas):
        self.stream.writelines(datas)
        self.stream.flush()

    def __getattr__(self, attr):
        return getattr(self.stream, attr)

def init(level=INFO, format='%(levelname)s%(message)s'):
    sys.stdout = Unbuffered(sys.stdout)

    basicConfig(level=level, format=format, )
    addLevelName(DEBUG, stylize("# [DEBUG] ", fg("grey_30")))
    addLevelName(INFO, '')
    addLevelName(WARNING, stylize(
        "# [WARNING] ", fg("dark_orange")))
    addLevelName(ERROR, stylize("# [ERROR] ", fg("red")))
    addLevelName(CRITICAL, stylize(
        "# [FAILURE] ", fg("light_red") + attr("bold")))
    addLevelName(SUCCESS, stylize(
        "# [SUCCESS] ", fg("green") + attr("bold")))

def logger(name='app'):
    log = getLogger(name)
    setattr(log, 'success', lambda message, *
    args: log._log(SUCCESS, message, args))
    return log



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
ezgooey
-------
Copyright (c) 2020 Adam Twardoch <adam+github@twardoch.com>
MIT license. Python 3.8+

See `ezgooey.ez` and `ezgooey.logging` for details.
"""
__version__ = "1.3.2"

__all__ = ['ez', 'logging']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
ezgooey.ez
----------

Copyright (c) 2020 Adam Twardoch <adam+github@twardoch.com>
MIT license. Python 3.8+

[Gooey](https://github.com/chriskiehl/Gooey) is a Python
package that lets you turn argparse-based CLI apps into
cross-platform GUI apps.
[ezgooey](https://github.com/twardoch/ezgooey) makes this
even simpler.

When you start your app without CLI arguments, it'll run
in GUI, but if you supply CLI arguments, it'll run as CLI.

Import, then add the `@ezgooey` decorator to the function
where you initialize the `ArgumentParser`.

```python
from ezgooey.ez import *

@ezgooey
def get_parser():
    parser = ArgumentParser(
        prog='appname',
        description='app description'
    )
...
```
"""
__version__ = '1.2.0'

import argparse
import sys
import functools

try:
    import gooey
except ImportError:
    gooey = None

# Monkey-patching a private class…


def flex_add_argument(f):
    """Make add_argument accept or ignore gooey-specific options."""

    def f_decorated(*args, **kwargs):
        kwargs.pop('widget', None)
        kwargs.pop('gooey_options', None)
        return f(*args, **kwargs)

    return f_decorated


def flex_add_argument_group(f):
    """Make add_argument_group accept or ignore gooey-specific options."""

    def f_decorated(*args, **kwargs):
        kwargs.pop('widget', None)
        kwargs.pop('gooey_options', None)
        return f(*args, **kwargs)

    return f_decorated


argparse._ActionsContainer.add_argument = flex_add_argument(
    argparse.ArgumentParser.add_argument)

argparse._ActionsContainer.add_argument_group = flex_add_argument_group(
    argparse.ArgumentParser.add_argument_group)

if gooey is None or len(sys.argv) > 1:
    ArgumentParser = argparse.ArgumentParser

    def ezgooey(*args, **kwargs):
        if args:
            return args[0]
        def decorator_ezgooey(func):
            return func
        return decorator_ezgooey

    s = """
    def ezgooey(*args, **kwargs):
        def decorator_ezgooey(func):
            @functools.wraps(func)
            def wrapper_ezgooey(*args, **kwargs):
                return func(*args, **kwargs)
            return wrapper_ezgooey
        return decorator_ezgooey
"""

else:
    ArgumentParser = gooey.GooeyParser

    def ezgooey(*args, **kwargs):
        return gooey.Gooey(*args, **kwargs)
